using System;
using System.Web;

using CMS.CMSHelper;
using CMS.GlobalHelper;
using CMS.PortalControls;
using CMS.WebAnalytics;
using CMS.FormEngine;
using CMS.SettingsProvider;
using CMS.DataEngine;
using System.Data;

public partial class CMSWebParts_BizForms_bizform_CustomRating : CMSAbstractWebPart
{
    #region "Properties"

    /// <summary>
    /// Gets or sets the form name of BizForm.
    /// </summary>
    public string BizFormName
    {
        get
        {
            return ValidationHelper.GetString(GetValue("BizFormName"), "");
        }
        set
        {
            SetValue("BizFormName", value);
        }
    }


    /// <summary>
    /// Gets or sets the alternative form full name (ClassName.AlternativeFormName).
    /// </summary>
    public string AlternativeFormName
    {
        get
        {
            return ValidationHelper.GetString(GetValue("AlternativeFormName"), "");
        }
        set
        {
            SetValue("AlternativeFormName", value);
        }
    }


    /// <summary>
    /// Gets or sets the site name.
    /// </summary>
    public string SiteName
    {
        get
        {
            return ValidationHelper.GetString(GetValue("SiteName"), "");
        }
        set
        {
            SetValue("SiteName", value);
        }
    }


    /// <summary>
    /// Gets or sets the value that indicates whether the WebPart use colon behind label.
    /// </summary>
    public bool UseColonBehindLabel
    {
        get
        {
            return ValidationHelper.GetBoolean(GetValue("UseColonBehindLabel"), true);
        }
        set
        {
            SetValue("UseColonBehindLabel", value);
        }
    }


    /// <summary>
    /// Gets or sets the message which is displayed after validation failed.
    /// </summary>
    public string ValidationErrorMessage
    {
        get
        {
            return ValidationHelper.GetString(GetValue("ValidationErrorMessage"), "");
        }
        set
        {
            SetValue("ValidationErrorMessage", value);
        }
    }


    /// <summary>
    /// Gets or sets the conversion track name used after successful registration.
    /// </summary>
    public string TrackConversionName
    {
        get
        {
            return ValidationHelper.GetString(GetValue("TrackConversionName"), "");
        }
        set
        {
            if (value.Length > 400)
            {
                value = value.Substring(0, 400);
            }
            SetValue("TrackConversionName", value);
        }
    }


    /// <summary>
    /// Gets or sets the conversion value used after successful registration.
    /// </summary>
    public double ConversionValue
    {
        get
        {
            return ValidationHelper.GetDoubleSystem(GetValue("ConversionValue"), 0);
        }
        set
        {
            SetValue("ConversionValue", value);
        }
    }

    #endregion


    #region "Methods"

    protected override void OnLoad(EventArgs e)
    {
        viewBiz.OnAfterSave += viewBiz_OnAfterSave;
        base.OnLoad(e);
    }


    /// <summary>
    /// Content loaded event handler.
    /// </summary>
    public override void OnContentLoaded()
    {
        base.OnContentLoaded();
        SetupControl();        
    }


    /// <summary>
    /// Reloads data for partial caching.
    /// </summary>
    public override void ReloadData()
    {
        base.ReloadData();
        SetupControl();
    }


    /// <summary>
    /// Initializes the control properties.
    /// </summary>
    protected void SetupControl()
    {
        if (StopProcessing)
        {
            // Do nothing
            viewBiz.StopProcessing = true;
        }
        else
        {
            // Set BizForm properties
            viewBiz.FormName = BizFormName;
            viewBiz.SiteName = SiteName;
            viewBiz.UseColonBehindLabel = UseColonBehindLabel;
            viewBiz.AlternativeFormFullName = AlternativeFormName;
            viewBiz.ValidationErrorMessage = ValidationErrorMessage;            

            // Set the live site context
            if (viewBiz.BasicForm != null)
            {
                viewBiz.BasicForm.ControlContext.ContextName = CMS.SiteProvider.ControlContext.LIVE_SITE;
            }

            viewBiz.OnBeforeSave += new EventHandler(viewBiz_OnBeforeSave);

        }
    }

    void viewBiz_OnBeforeSave(object sender, EventArgs e)
    {
        // Read Form definition
        BizFormInfo bfi = BizFormInfoProvider.GetBizFormInfo(this.viewBiz.FormName , CMSContext.CurrentSiteName);
        if (bfi != null)
        {
            // Read data type definition
            DataClassInfo dci = DataClassInfoProvider.GetDataClass(bfi.FormClassID);
            if (dci != null)
            {

                // Get all Form data
                GeneralConnection genConn = ConnectionHelper.GetConnection();
                DataSet ds = genConn.ExecuteQuery(dci.ClassName + ".selectall", null, "DocumentGUID ='" + CurrentDocument.DocumentGUID  + "'");
                if (!DataHelper.DataSourceIsEmpty(ds))
                {

                    // Get ID of the first record
                    int formRecordID = ValidationHelper.GetInteger(ds.Tables[0].Rows[0][0], 0);

                    BizFormItemProvider bProvider = new BizFormItemProvider();
                    // Get the record with ID of the first row record
                    BizFormItem formRecord = bProvider.GetItem(formRecordID, dci.ClassName);

                    if (formRecord != null)
                    {

                        // Set new field values
                        formRecord.SetValue("Trustworthy", formRecord.GetIntegerValue("Trustworthy", 0) + ValidationHelper.GetInteger(viewBiz.BasicForm.GetFieldValue("Trustworthy"), 0));
                        formRecord.SetValue("Objective", formRecord.GetIntegerValue("Objective", 0) + ValidationHelper.GetInteger(viewBiz.BasicForm.GetFieldValue("Objective"), 0));
                        formRecord.SetValue("Complete", formRecord.GetIntegerValue("Complete", 0) + ValidationHelper.GetInteger(viewBiz.BasicForm.GetFieldValue("Complete"), 0));
                        formRecord.SetValue("WellWritten",  formRecord.GetIntegerValue("WellWritten", 0) + ValidationHelper.GetInteger(viewBiz.BasicForm.GetFieldValue("WellWritten"), 0));
                        formRecord.SetValue("DocumentRatings", formRecord.GetIntegerValue("DocumentRatings", 0) + 1);

                        try
                        {
                            // Save updates in the database
                            formRecord.Update();

                            // Show success message
                            lblInfo.Visible = true;
                            lblInfo.Text = bfi.FormDisplayText;

                            // Stop processing of the form and hide it.
                            this.viewBiz.StopProcessing = true;
                            this.viewBiz.Visible = false;
                        }
                        catch {}
                    }
                }
                else
                {

                    // Let the BizForm to save the record for the first time.
                }
            }
        }
    }


    private void viewBiz_OnAfterSave(object sender, EventArgs e)
    {
        if (TrackConversionName != String.Empty)
        {
            string siteName = CMSContext.CurrentSiteName;

            if (AnalyticsHelper.AnalyticsEnabled(siteName) && AnalyticsHelper.TrackConversionsEnabled(siteName) && !AnalyticsHelper.IsIPExcluded(siteName, HTTPHelper.UserHostAddress))
            {
                HitLogProvider.LogConversions(CMSContext.CurrentSiteName, CMSContext.PreferredCultureCode, TrackConversionName, 0, ConversionValue);
            }
        }
    }

    #endregion
}