using System;

using CMS.CMSHelper;
using CMS.SettingsProvider;
using CMS.GlobalHelper;
using CMS.UIControls;
using CMS.PortalControls;
using System.Data;
using CMS.SiteProvider;

public partial class CustomTableForm : CMSAbstractWebPart
{
    #region "Private variables"

   
    private DataClassInfo dci = null;

    #endregion


    #region "Public properties"

    /// <summary>
    /// Custom table class name
    /// </summary>
    /// 
    /// <summary>
    /// Gets or sets the form name of CustomTable
    /// </summary>
    /// 

    public string CustomTableName
    {
        get
        {
            return ValidationHelper.GetString(GetValue("CustomTableName"), "");
        }

        set
        {
            this.SetValue("CustomTableName", value);
        }

    }

   
  

    public string ShowItemAfterSave
    {
        get
        {
            return ValidationHelper.GetString(GetValue("ShowItemAfterSave"), "");
        }
        set
        {
            this.SetValue("ShowItemAfterSave", value);
        }
    }

    


    /// <summary>
    /// Gets or sets the site name
    /// </summary>
    public string SiteName
    {
        get
        {
            return ValidationHelper.GetString(GetValue("SiteName"), "");
        }
        set
        {
            this.SetValue("SiteName", value);
        }
    }


    /// <summary>
    /// Gets or sets the value that indicates whether the WebPart use colon behind label
    /// </summary>
    public bool UseColonBehindLabel
    {
        get
        {
              return ValidationHelper.GetBoolean(GetValue("UseColonBehindLabel"), true);
        }
        set
        {
            this.SetValue("UseColonBehindLabel", value);
        }
    }

    #endregion


    protected void Page_Load(object sender, EventArgs e)
    {

        SetupControl();
    
      
    }
 

    private void SetupControl()
    {

        if (!string.IsNullOrEmpty(CustomTableName))
        {
            // Get form info
            dci = DataClassInfoProvider.GetDataClass(CustomTableName);
            customTableForm.CustomTableId = dci.ClassID;
            customTableForm.SiteName = SiteName;
            customTableForm.UseColonBehindLabel = UseColonBehindLabel;
            customTableForm.ItemID =0;

            if (dci != null)
            {
                customTableForm.ShowPrivateFields = true;
                customTableForm.OnAfterSave += new EventHandler(customTableForm_OnAfterSave);
                customTableForm.OnBeforeSave += new EventHandler(customTableForm_OnBeforeSave);
            }
        }
    }


    void customTableForm_OnBeforeSave(object sender, EventArgs e)
    {

        // Creates a new Custom table item provider
        CustomTableItemProvider customTableProvider = new CustomTableItemProvider(CMSContext.CurrentUser);

        // Checks if Custom table 'Sample table' exists
        DataClassInfo customTable = DataClassInfoProvider.GetDataClass(CustomTableName);

        if (customTable != null)
        {
            // Prepares the parameters
            string where = "DocumentGUID = '" + CurrentDocument.DocumentGUID +  "'";
            int topN = 1;

            // Gets the data set according to the parameters
            DataSet dataSet = customTableProvider.GetItems(CustomTableName, where, null, topN, "ItemID");
            if (!DataHelper.DataSourceIsEmpty(dataSet))
            {
                // Gets the custom table item ID
                int itemID = ValidationHelper.GetInteger(dataSet.Tables[0].Rows[0][0], 0);

                // Gets the custom table item
                CustomTableItem updateCustomTableItem = customTableProvider.GetItem(itemID, CustomTableName);

                if (updateCustomTableItem != null)
                {
                    // Set new field values
                    updateCustomTableItem.SetValue("Trustworthy", updateCustomTableItem.GetIntegerValue("Trustworthy", 0) + ValidationHelper.GetInteger(customTableForm.BasicForm.GetFieldValue("Trustworthy"), 0));
                    updateCustomTableItem.SetValue("Objective", updateCustomTableItem.GetIntegerValue("Objective", 0) + ValidationHelper.GetInteger(customTableForm.BasicForm.GetFieldValue("Objective"), 0));
                    updateCustomTableItem.SetValue("Complete", updateCustomTableItem.GetIntegerValue("Complete", 0) + ValidationHelper.GetInteger(customTableForm.BasicForm.GetFieldValue("Complete"), 0));
                    updateCustomTableItem.SetValue("WellWritten", updateCustomTableItem.GetIntegerValue("WellWritten", 0) + ValidationHelper.GetInteger(customTableForm.BasicForm.GetFieldValue("WellWritten"), 0));
                    updateCustomTableItem.SetValue("DocumentRatings", updateCustomTableItem.GetIntegerValue("DocumentRatings", 0) + 1);

                    try
                    {
                        // Saves the changes
                        updateCustomTableItem.Update();

                        // Show success message
                        lblInfo.Text = ResHelper.GetString("general.changessaved");
                        lblInfo.Visible = true;

                        // Stop processing of the form and hide it.
                        this.customTableForm.StopProcessing = true;
                        this.customTableForm.Visible = false;
                    }
                    catch { }
                }
            }
        }
    }


    void customTableForm_OnAfterSave(object sender, EventArgs e)
    {
        lblInfo.Text = ResHelper.GetString("general.changessaved");
        lblInfo.Visible = true;
        customTableForm.Visible = false;
    }
 
}
