using System;
using System.Data;

using CMS.CMSHelper;
using CMS.SettingsProvider;
using CMS.GlobalHelper;
using CMS.UIControls;
using CMS.PortalControls;
using CMS.SiteProvider;
using CMS.FormEngine;
using CMS.OnlineMarketing;

public partial class WebinarSampleSite_CMSWebParts_CustomTables_CustomTableFormCustomDocumentRating : CMSAbstractWebPart
{
    #region "Private variables"

   
    private DataClassInfo dci = null;

    #endregion


    #region "Public properties"

    /// <summary>
    /// Custom table class name
    /// </summary>
    /// 
    /// <summary>
    /// Gets or sets the form name of CustomTable
    /// </summary>
    /// 

    public string CustomTableName
    {
        get
        {
            return ValidationHelper.GetString(GetValue("CustomTableName"), "");
        }

        set
        {
            this.SetValue("CustomTableName", value);
        }

    }

   
  

    public string ShowItemAfterSave
    {
        get
        {
            return ValidationHelper.GetString(GetValue("ShowItemAfterSave"), "");
        }
        set
        {
            this.SetValue("ShowItemAfterSave", value);
        }
    }

    


    /// <summary>
    /// Gets or sets the site name
    /// </summary>
    public string SiteName
    {
        get
        {
            return ValidationHelper.GetString(GetValue("SiteName"), "");
        }
        set
        {
            this.SetValue("SiteName", value);
        }
    }


    /// <summary>
    /// Gets or sets the value that indicates whether the WebPart use colon behind label
    /// </summary>
    public bool UseColonBehindLabel
    {
        get
        {
              return ValidationHelper.GetBoolean(GetValue("UseColonBehindLabel"), true);
        }
        set
        {
            this.SetValue("UseColonBehindLabel", value);
        }
    }

    #endregion


    #region "Methods"

    protected void Page_Load(object sender, EventArgs e)
    {
        SetupControl();
    }
 

    private void SetupControl()
    {

        if (!string.IsNullOrEmpty(CustomTableName))
        {
            // Get form info
            dci = DataClassInfoProvider.GetDataClass(CustomTableName);
            customTableForm.CustomTableId = dci.ClassID;
            customTableForm.SiteName = SiteName;
            customTableForm.UseColonBehindLabel = UseColonBehindLabel;
            customTableForm.ItemID =0;

            if (dci != null)
            {
                customTableForm.ShowPrivateFields = true;
                customTableForm.OnAfterSave += new EventHandler(customTableForm_OnAfterSave);
                customTableForm.OnBeforeSave += new EventHandler(customTableForm_OnBeforeSave);
            }
        }
    }


    void customTableForm_OnBeforeSave(object sender, EventArgs e)
    {
        // Creates a new Custom table item provider
        CustomTableItemProvider customTableProvider = new CustomTableItemProvider(CMSContext.CurrentUser);

        // Checks if Custom table exists
        DataClassInfo customTable = DataClassInfoProvider.GetDataClass(CustomTableName);

        if (customTable != null)
        {
            // Load form definition
            FormInfo fi = new FormInfo(customTable.ClassFormDefinition);

            foreach (var item in fi.GetFields(true, true, false, false))
            {
                switch (item.Name.ToLower())
                {
                    case "itemid":
                    case "documentguid":
                    case "knowledgeable":
                        break;
                    default:
                        CurrentDocument.DocumentCustomData[item.Name.ToLower()] = ValidationHelper.GetInteger(CurrentDocument.DocumentCustomData[item.Name.ToLower()], 0) + ValidationHelper.GetInteger(customTableForm.BasicForm.GetFieldValue(item.Name), 0);
                        break;
                }
            }

            try
            {
                // Saves the changes
                CurrentDocument.Update();
                
                //this.customTableForm.StopProcessing = true;
            }
            catch { }
        }
    }


    void customTableForm_OnAfterSave(object sender, EventArgs e)
    {
        // Show success message
        lblInfo.Text = ResHelper.GetString("general.changessaved");
        lblInfo.Visible = true;
        customTableForm.Visible = false;

        // Create custom OM activity
        if (SettingsKeyProvider.GetBoolValue(CurrentSiteName + ".CMSEnableOnlineMarketing"))
        {
            // Create new activity object
            ActivityInfo newActivity = new ActivityInfo()
            {
                ActivityType = "CustomDocumentRating",
                ActivityTitle = "Custom Document Rating",
                ActivitySiteID = CMSContext.CurrentSiteID,
                ActivityActiveContactID = OnlineMarketingContext.CurrentContactID,
                ActivityOriginalContactID = OnlineMarketingContext.CurrentContactID,
                ActivityURL = URLHelper.CurrentURL,
                ActivityValue = customTableForm.BasicForm.GetFieldValue("ItemID").ToString(),
            };

            // Save the activity
            ActivityInfoProvider.SetActivityInfo(newActivity);
        }
    }

    #endregion
}
